pub struct CcacheError(pub String);Expand description
Problem representing an error from the ccache compiler cache.
This struct is used when the ccache tool, which accelerates repeated compilations, encounters an error during its operation.
Tuple Fields
0: StringImplementations