pub struct DhWithOrderIncorrect;Expand description
Problem representing incorrect debhelper (dh) command argument order.
This struct is used when the debhelper command is used with arguments in an incorrect order, which can cause build issues in Debian packaging.