pub struct DirectoryNonExistant(pub String);Expand description
Problem representing a directory that does not exist.
This struct is used when a build process expects a directory to exist but it cannot be found in the filesystem.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for DirectoryNonExistant
impl Clone for DirectoryNonExistant
Sourcefn clone(&self) -> DirectoryNonExistant
fn clone(&self) -> DirectoryNonExistant
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DirectoryNonExistant
impl Debug for DirectoryNonExistant
Sourceimpl Display for DirectoryNonExistant
impl Display for DirectoryNonExistant
Sourceimpl Problem for DirectoryNonExistant
impl Problem for DirectoryNonExistant
Sourcefn is_universal(&self) -> bool
fn is_universal(&self) -> bool
Is this problem universal, i.e. applicable to all build steps? Read more