pub struct InvalidCurrentUser(pub String);Expand description
Problem representing an invalid current user for a build operation.
This struct is used when a build process encounters issues because it’s running under an unexpected or inappropriate user account.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for InvalidCurrentUser
impl Clone for InvalidCurrentUser
Sourcefn clone(&self) -> InvalidCurrentUser
fn clone(&self) -> InvalidCurrentUser
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InvalidCurrentUser
impl Debug for InvalidCurrentUser
Sourceimpl Display for InvalidCurrentUser
impl Display for InvalidCurrentUser
Sourceimpl Problem for InvalidCurrentUser
impl Problem for InvalidCurrentUser
Sourcefn is_universal(&self) -> bool
fn is_universal(&self) -> bool
Is this problem universal, i.e. applicable to all build steps? Read more