pub struct MissingCMakeConfig {
pub name: String,
pub version: Option<String>,
}Expand description
Problem representing a missing CMake package configuration.
This struct is used when a CMake-based build process cannot find a required package configuration file.
Fields
name: StringThe name of the CMake package.
version: Option<String>The version of the package that was requested, if specified.