pub struct MissingDHCompatLevel {
pub command: String,
}Expand description
Problem representing a missing debhelper compatibility level specification.
This struct is used when debhelper requires a compatibility level to be specified, but none was found in the expected locations.
Fields
command: StringThe command that reported the missing compatibility level.
Implementations