pub struct MissingGoModFile;Expand description
Problem representing a missing Go module file.
This struct is used when a Go project requires a go.mod file for module and dependency management, but the file is missing.