pub struct MissingGoRuntime;Expand description
Problem representing a missing Go runtime.
This struct is used when a build process requires the Go language runtime but it is not installed or cannot be found in the system.