pub struct MissingGoSumEntry {
pub package: String,
pub version: String,
}Expand description
Problem representing a missing entry in the Go checksum file.
This struct is used when a Go project requires an entry in the go.sum file for a specific package version, but the entry is missing.
Fields
package: StringThe package import path.
version: StringThe version of the package.