pub struct MissingJDKFile {
pub jdk_path: String,
pub filename: String,
}Expand description
Problem representing a missing file in the Java Development Kit.
This struct is used when a build requires a specific file from the JDK but it cannot be found in the JDK directory.
Fields
jdk_path: StringThe path to the JDK directory.
filename: StringThe name of the file that is missing from the JDK.
Implementations