pub struct MissingJavaClass {
pub classname: String,
}Expand description
Problem representing a missing Java class.
This struct is used when a Java application or build process requires a Java class that cannot be found in the classpath.
Fields
classname: StringThe name of the missing Java class.
Implementations