pub struct MissingLibtool;Expand description
Problem representing missing GNU Libtool.
This struct is used when a build process requires the GNU Libtool utility for creating portable shared libraries, but it is not installed.
Implementations