pub struct MissingLuaModule(pub String);Expand description
Problem representing a missing Lua module.
This struct is used when a Lua script or application attempts to load a Lua module that is not installed or cannot be found.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for MissingLuaModule
impl Clone for MissingLuaModule
Sourcefn clone(&self) -> MissingLuaModule
fn clone(&self) -> MissingLuaModule
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MissingLuaModule
impl Debug for MissingLuaModule
Sourceimpl Display for MissingLuaModule
impl Display for MissingLuaModule
Sourceimpl Problem for MissingLuaModule
impl Problem for MissingLuaModule
Sourcefn is_universal(&self) -> bool
fn is_universal(&self) -> bool
Is this problem universal, i.e. applicable to all build steps? Read more