pub struct MissingPerlDistributionFile(pub String);Expand description
Problem representing a missing file in a Perl distribution.
This struct is used when a Perl module build or installation process cannot find a required file that should be part of the distribution.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for MissingPerlDistributionFile
impl Clone for MissingPerlDistributionFile
Sourcefn clone(&self) -> MissingPerlDistributionFile
fn clone(&self) -> MissingPerlDistributionFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MissingPerlDistributionFile
impl Debug for MissingPerlDistributionFile
Sourceimpl Problem for MissingPerlDistributionFile
impl Problem for MissingPerlDistributionFile
Sourcefn is_universal(&self) -> bool
fn is_universal(&self) -> bool
Is this problem universal, i.e. applicable to all build steps? Read more