pub struct MissingPerlFile {
pub filename: String,
pub inc: Option<Vec<String>>,
}Expand description
Problem representing a missing Perl file.
This struct is used when a Perl script attempts to load a file but it cannot be found in any of the include paths.
Fields
filename: StringThe name of the missing Perl file.
inc: Option<Vec<String>>The include paths that were searched, if available.
Implementations