pub struct MissingPostgresExtension(pub String);Expand description
Problem representing a missing PostgreSQL extension.
This struct is used when a build or runtime requires a PostgreSQL extension that is not installed or cannot be found.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for MissingPostgresExtension
impl Clone for MissingPostgresExtension
Sourcefn clone(&self) -> MissingPostgresExtension
fn clone(&self) -> MissingPostgresExtension
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MissingPostgresExtension
impl Debug for MissingPostgresExtension
Sourceimpl Display for MissingPostgresExtension
impl Display for MissingPostgresExtension
Sourceimpl Problem for MissingPostgresExtension
impl Problem for MissingPostgresExtension
Sourcefn is_universal(&self) -> bool
fn is_universal(&self) -> bool
Is this problem universal, i.e. applicable to all build steps? Read more