pub struct MissingRubyGem {
pub gem: String,
pub version: Option<String>,
}Expand description
Problem representing a missing Ruby gem.
This struct is used when a build process requires a Ruby gem that is not installed or available in the current environment.
Fields
gem: StringThe name of the missing Ruby gem.
version: Option<String>The required version of the gem, if specified.
Implementations