pub struct MissingSetupPyCommand(pub String);Expand description
Problem representing a missing command in a Python setup.py script.
This struct is used when a Python setup.py script is called with a command that it does not support or recognize.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for MissingSetupPyCommand
impl Clone for MissingSetupPyCommand
Sourcefn clone(&self) -> MissingSetupPyCommand
fn clone(&self) -> MissingSetupPyCommand
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MissingSetupPyCommand
impl Debug for MissingSetupPyCommand
Sourceimpl Display for MissingSetupPyCommand
impl Display for MissingSetupPyCommand
Sourceimpl Problem for MissingSetupPyCommand
impl Problem for MissingSetupPyCommand
Sourcefn is_universal(&self) -> bool
fn is_universal(&self) -> bool
Is this problem universal, i.e. applicable to all build steps? Read more