pub struct MissingSprocketsFile {
pub name: String,
pub content_type: String,
}Expand description
Problem representing a missing Sprockets asset file.
This struct is used when a Ruby on Rails application using the Sprockets asset pipeline is missing a required asset file.
Fields
name: StringThe name of the missing Sprockets asset file.
content_type: StringThe content type of the missing asset file.
Implementations