pub struct NeedPgBuildExtUpdateControl {
pub generated_path: String,
pub template_path: String,
}Expand description
Problem representing a need to update PostgreSQL build extension control files.
This struct is used when PostgreSQL extension build files need to be updated using the pg_buildext updatecontrol command to generate control files from templates.
Fields
generated_path: StringThe path to the generated control file.
template_path: StringThe path to the template file to use for generation.
Implementations