pub struct NotExecutableFile(pub String);Expand description
Problem representing a file that is not executable.
This struct is used when a command or script file that needs to be executed does not have the executable permission bit set.
Tuple Fields
0: StringImplementations