pub struct TooManyOpenFiles;Expand description
Problem representing a “too many open files” error.
This struct is used when a process hits the system limit for the number of files that can be opened simultaneously, often due to a resource leak.