pub struct UnsupportedPytestArguments(pub Vec<String>);Expand description
Problem representing unsupported pytest command-line arguments.
This struct is used when pytest is invoked with command-line arguments that are not supported in the current environment.
Tuple Fields
0: Vec<String>Trait Implementations
Sourceimpl Clone for UnsupportedPytestArguments
impl Clone for UnsupportedPytestArguments
Sourcefn clone(&self) -> UnsupportedPytestArguments
fn clone(&self) -> UnsupportedPytestArguments
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnsupportedPytestArguments
impl Debug for UnsupportedPytestArguments
Sourceimpl Display for UnsupportedPytestArguments
impl Display for UnsupportedPytestArguments
Sourceimpl Problem for UnsupportedPytestArguments
impl Problem for UnsupportedPytestArguments
Sourcefn is_universal(&self) -> bool
fn is_universal(&self) -> bool
Is this problem universal, i.e. applicable to all build steps? Read more