pub struct UnsupportedPytestConfigOption(pub String);Expand description
Problem representing an unsupported pytest configuration option.
This struct is used when a pytest configuration specifies an option that is not supported in the current environment.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for UnsupportedPytestConfigOption
impl Clone for UnsupportedPytestConfigOption
Sourcefn clone(&self) -> UnsupportedPytestConfigOption
fn clone(&self) -> UnsupportedPytestConfigOption
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Problem for UnsupportedPytestConfigOption
impl Problem for UnsupportedPytestConfigOption
Sourcefn is_universal(&self) -> bool
fn is_universal(&self) -> bool
Is this problem universal, i.e. applicable to all build steps? Read more