pub struct UpstartFilePresent(pub String);Expand description
Problem representing the presence of an upstart configuration file.
This struct is used to indicate that a package includes an upstart file, which may be problematic in environments that have moved to systemd.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for UpstartFilePresent
impl Clone for UpstartFilePresent
Sourcefn clone(&self) -> UpstartFilePresent
fn clone(&self) -> UpstartFilePresent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpstartFilePresent
impl Debug for UpstartFilePresent
Sourceimpl Display for UpstartFilePresent
impl Display for UpstartFilePresent
Sourceimpl Problem for UpstartFilePresent
impl Problem for UpstartFilePresent
Sourcefn is_universal(&self) -> bool
fn is_universal(&self) -> bool
Is this problem universal, i.e. applicable to all build steps? Read more