ValaCompilerCannotCompile

Struct ValaCompilerCannotCompile 

pub struct ValaCompilerCannotCompile;
Problem representing an issue with the Vala compiler.

This struct is used when the Vala compiler (valac) encounters an error that prevents it from compiling Vala source code.