pub struct DpkgBinaryFileChanged(pub Vec<String>);Expand description
Problem representing changes to binary files in the source package.
This struct is used when dpkg-source detects that binary files have been changed, which cannot be properly represented in source package formats.
Tuple Fields
0: Vec<String>Trait Implementations
Sourceimpl Clone for DpkgBinaryFileChanged
impl Clone for DpkgBinaryFileChanged
Sourcefn clone(&self) -> DpkgBinaryFileChanged
fn clone(&self) -> DpkgBinaryFileChanged
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DpkgBinaryFileChanged
impl Debug for DpkgBinaryFileChanged
Sourceimpl Display for DpkgBinaryFileChanged
impl Display for DpkgBinaryFileChanged
Sourceimpl Problem for DpkgBinaryFileChanged
impl Problem for DpkgBinaryFileChanged
Sourcefn is_universal(&self) -> bool
fn is_universal(&self) -> bool
Is this problem universal, i.e. applicable to all build steps? Read more