pub struct DpkgSourceLocalChanges {
pub diff_file: Option<String>,
pub files: Option<Vec<String>>,
}Expand description
Problem representing unexpected local changes in the source package.
This struct is used when dpkg-source detects unexpected local changes to upstream source code, which should be represented as patches instead.
Fields
diff_file: Option<String>Path to the diff file showing the changes, if available.
files: Option<Vec<String>>List of files that have been changed locally, if available.