pub struct DpkgSourceUnrepresentableChanges;Expand description
Problem representing changes that cannot be represented in the source package.
This struct is used when dpkg-source detects changes that cannot be represented in the chosen source format, such as mode changes in some formats.