pub struct InconsistentSourceFormat {
pub version: bool,
pub source_format: bool,
}Expand description
Problem representing inconsistency between source format and version.
This struct is used when there’s an inconsistency between the source format specified in debian/source/format and the version numbering scheme.
Fields
version: boolWhether the version is inconsistent with the source format.
source_format: boolWhether the source format is inconsistent with the version.