pub struct PatchFileMissing(pub PathBuf);Expand description
Problem representing a missing patch file.
This struct is used when a build requires a patch file that is referenced in the debian/patches directory but is not found.
Tuple Fields
0: PathBufTrait Implementations
Sourceimpl Clone for PatchFileMissing
impl Clone for PatchFileMissing
Sourcefn clone(&self) -> PatchFileMissing
fn clone(&self) -> PatchFileMissing
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PatchFileMissing
impl Debug for PatchFileMissing
Sourceimpl Display for PatchFileMissing
impl Display for PatchFileMissing
Sourceimpl Problem for PatchFileMissing
impl Problem for PatchFileMissing
Sourcefn is_universal(&self) -> bool
fn is_universal(&self) -> bool
Is this problem universal, i.e. applicable to all build steps? Read more