pub struct SourceFormatUnbuildable {
pub source_format: String,
pub reason: String,
}Expand description
Problem representing a source format that cannot be built.
This struct is used when the source package format specified in debian/source/format cannot be built for some reason.
Fields
source_format: StringThe source format that can’t be built (e.g., “3.0 (quilt)”).
reason: StringThe reason why the source format cannot be built.