pub struct SourceFormatUnsupported(pub String);Expand description
Problem representing a source format that is not supported.
This struct is used when the source package format specified in debian/source/format is not supported by the build environment.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for SourceFormatUnsupported
impl Clone for SourceFormatUnsupported
Sourcefn clone(&self) -> SourceFormatUnsupported
fn clone(&self) -> SourceFormatUnsupported
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SourceFormatUnsupported
impl Debug for SourceFormatUnsupported
Sourceimpl Display for SourceFormatUnsupported
impl Display for SourceFormatUnsupported
Sourceimpl Problem for SourceFormatUnsupported
impl Problem for SourceFormatUnsupported
Sourcefn is_universal(&self) -> bool
fn is_universal(&self) -> bool
Is this problem universal, i.e. applicable to all build steps? Read more