UScanError

Struct UScanError 

pub struct UScanError(pub String);
Problem representing a generic error in the uscan tool.

This struct is used when the uscan tool, which checks for upstream versions, encounters an error that doesn’t fit into more specific categories.

Tuple Fields

0: String