pub struct UpstreamMetadataFileParseError {
pub path: PathBuf,
pub reason: String,
}Expand description
Problem representing an error parsing the debian/upstream/metadata file.
This struct is used when the build process cannot parse the debian/upstream/metadata file, which contains information about the upstream project.
Fields
path: PathBufThe path to the metadata file.
reason: StringThe reason for the parsing failure.