pub struct UScanError(pub String);Expand description
Problem representing a generic error in the uscan tool.
This struct is used when the uscan tool, which checks for upstream versions, encounters an error that doesn’t fit into more specific categories.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for UScanError
impl Clone for UScanError
Sourcefn clone(&self) -> UScanError
fn clone(&self) -> UScanError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UScanError
impl Debug for UScanError
Sourceimpl Display for UScanError
impl Display for UScanError
Sourceimpl Problem for UScanError
impl Problem for UScanError
Sourcefn is_universal(&self) -> bool
fn is_universal(&self) -> bool
Is this problem universal, i.e. applicable to all build steps? Read more